Incomplete awlsim TODO list
===========================

S7 compatibility
----------------

* Implement parsing of attributes

core
----

* Blocks that are no longer linked to (created by) sources should be removed.
* Single download of symtab causes a redefinition error.

GUI
---

* Save window status (open MDI windows, positions, etc)
* Show UDTs in block tree
* Add a FBD (FUP) (de-)compiler
* Add a LAD (KOP) (de-)compiler
